@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2017 sqlmap developers (http://sqlmap.org/)
+Copyright (c) 2006-2018 sqlmap developers (http://sqlmap.org/)
 See the file 'LICENSE' for copying permission
 """
 
@@ -139,7 +139,7 @@ optDict = {
                                "db":                "string",
                                "tbl":               "string",
                                "col":               "string",
-                               "excludeCol":        "string",
+                               "exclude":           "string",
                                "pivotColumn":       "string",
                                "dumpWhere":         "string",
                                "user":              "string",
